# tree-sitter-talon

![GitHub package.json version](https://img.shields.io/github/package-json/v/wenkokke/tree-sitter-talon) ![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/wenkokke/tree-sitter-talon) ![npm](https://img.shields.io/npm/v/tree-sitter-talon) ![GitHub Workflow Status](https://img.shields.io/github/workflow/status/wenkokke/tree-sitter-talon/CI) ![GitHub](https://img.shields.io/github/license/wenkokke/tree-sitter-talon)

Unofficial Talon file grammar for [tree-sitter].

References:
- [Talon Community Wiki - .talon Files][talon-wiki]

Tested with:
- [knausj_talon]
- [andreas-talon]
- [talon-axkit]
- [nriley's knausj_talon]

If you would like to include your Talon user directory as part of the tests, please submit a pull request adding the relevant information to [`script/parse-examples`](script/parse-examples#L32-L37) and this file.

[tree-sitter]: https://github.com/tree-sitter/tree-sitter
[talon-wiki]: https://talon.wiki/unofficial_talon_docs/#talon-files
[knausj_talon]: https://github.com/knausj85/knausj_talon
[andreas-talon]: https://github.com/AndreasArvidsson/andreas-talon
[talon-axkit]: https://github.com/phillco/talon-axkit
[nriley's knausj_talon]: https://github.com/nriley/knausj_talon